from typing import Literal

Icon = Literal[
    "AWS",
    "Airflow",
    "AmazonEKS",
    "AmazonRDS",
    "Amplication",
    "Ansible",
    "ApiDoc",
    "AppRunner",
    "Aqua",
    "Argo",
    "ArgoRollouts",
    "Armis",
    "Azure",
    "AzureAD",
    "AzureDevops",
    "AzurePipline",
    "AzureProvider",
    "Backstage",
    "BitBucket",
    "BitBucketGitops",
    "BlankPage",
    "Buddy",
    "CICD",
    "CPlusPlus",
    "CSharp",
    "CircleCI",
    "Clickup",
    "CloudFormation",
    "Cloudflare",
    "Cluster",
    "Codacy",
    "Codecov",
    "Codefresh",
    "ConcourseCI",
    "Confluence",
    "Consul",
    "Cookiecutter",
    "Coralogix",
    "Crossplane",
    "DBT",
    "Databricks",
    "Datadog",
    "Day2Operation",
    "Dependabot",
    "Docker",
    "DrawIO",
    "Dynatrace",
    "EC2",
    "EU",
    "Ecs",
    "ElasticSearch",
    "Environments",
    "Falcosidekick",
    "Figma",
    "FireHydrant",
    "Flagsmith",
    "Fluentd",
    "Fluxcd",
    "Flyway",
    "GCE",
    "GKE",
    "Git",
    "GitIssue",
    "GitLab",
    "GitLabGitops",
    "GitPullRequest",
    "GitSubIcon",
    "GitVersion",
    "Github",
    "GithubActions",
    "GithubCopilot",
    "GithubGitops",
    "Go",
    "Google",
    "GoogleCloud",
    "GoogleCloudPlatform",
    "GoogleMaps",
    "Grafana",
    "Graphql",
    "HAProxy",
    "HashiCorp",
    "Helm",
    "Hubspot",
    "Humio",
    "Istio",
    "JFrog",
    "Javascript",
    "Jenkins",
    "JfrogXray",
    "Jira",
    "JumpCloudProvider",
    "Jupyter",
    "KNative",
    "Kafka",
    "KafkaUI",
    "Kiali",
    "Komodor",
    "Kotlin",
    "Kubecost",
    "Kyverno",
    "Lambda",
    "Lastpass",
    "Launchdarkly",
    "Linear",
    "Linux",
    "Logz",
    "LucidCharts",
    "Matlab",
    "Microservices",
    "Microsoft",
    "MicrosoftEntraID",
    "Miro",
    "Mixpanel",
    "MongoDb",
    "NSQ",
    "Neo4j",
    "NewRelic",
    "NodeJS",
    "Notion",
    "Ocean",
    "Octopus",
    "Okta",
    "OneLogin",
    "Opencost",
    "OpsGenie",
    "OutSystems",
    "Perl",
    "Port",
    "PostgreSQL",
    "Prometheus",
    "Pulsar",
    "Pulumi",
    "Python",
    "R",
    "Rancher",
    "React",
    "RedhatOpenshift",
    "Redis",
    "Ruby",
    "S3",
    "SDK",
    "SNS",
    "SQL",
    "SalesForce",
    "Scala",
    "SendGrid",
    "Sensu",
    "Sentry",
    "Servicenow",
    "Sinch",
    "SingleStore",
    "Slack",
    "Snowflake",
    "Snyk",
    "SonarCloud",
    "SonartypeNexusIQ",
    "Spring",
    "StackOverflow",
    "Stackhawk",
    "StatusPage",
    "Stonebranch",
    "Stoplight",
    "Stripe",
    "Swagger",
    "Swift",
    "Tableau",
    "TeamCity",
    "Terraform",
    "Thanos",
    "Trivy",
    "Twilio",
    "TwoUsers",
    "Typescript",
    "USA",
    "Unleash",
    "Webhook",
    "Windows",
    "Wiz",
    "Youtrack",
    "Zendesk",
    "Zipkin",
    "checkmarx",
    "css3",
    "groundcover",
    "html5",
    "java",
    "js",
    "kibana",
    "pagerduty",
    "php",
    "sonarqube",
    "spinnaker",
    "AI",
    "APIEndpoint",
    "APIalt",
    "Actions",
    "Add",
    "AddUser",
    "Alert",
    "Apps",
    "AuditLog",
    "BadgeAlert",
    "Bar",
    "Blueprint",
    "Bolt",
    "Book",
    "Box",
    "Branch",
    "Bucket",
    "Bug",
    "Bulb",
    "CPU",
    "CSV",
    "Calendar",
    "Catalog",
    "Chat",
    "Checklist",
    "Clock",
    "ClockLoader",
    "ClosedFolder",
    "Cloud",
    "Code",
    "CodeBlocks",
    "Columns",
    "Commit",
    "Cost",
    "Database",
    "DefaultBlueprint",
    "DefaultProperty",
    "Delete",
    "DeployedAt",
    "Deployment",
    "Details",
    "DevTV",
    "DevopsTool",
    "Docs",
    "DownArrow",
    "Download",
    "Drive",
    "DynamicFeed",
    "Edit",
    "Emergency",
    "EmptyBox",
    "Environment",
    "ErrorLogs",
    "Euro",
    "Event",
    "Exporter",
    "Finance",
    "FitView",
    "Flag",
    "GPU",
    "General",
    "GroupBy",
    "Health",
    "Help",
    "Home",
    "HourGlass",
    "HourGlassExpired",
    "IaC",
    "Infinity",
    "Instance",
    "Job",
    "JsonEditor",
    "Key",
    "Layers",
    "Learn",
    "LeftArrow",
    "LineChart",
    "Link",
    "LinkOut",
    "List",
    "Lock",
    "LogOut",
    "Mail",
    "ManageSearch",
    "Manager",
    "Markdown",
    "Merge",
    "Metric",
    "Microservice",
    "Migrate",
    "Misconfiguration",
    "Moon",
    "Move",
    "NewPage",
    "Node",
    "OpenFolder",
    "Organization",
    "Package",
    "Permissions",
    "Pie",
    "Pipeline",
    "Plug",
    "PlugOff",
    "Properties",
    "Register",
    "Relation",
    "Reminder",
    "Repeat",
    "Reset",
    "RestAPI",
    "RightArrow",
    "Rocket",
    "Role",
    "Rope",
    "Score",
    "Search",
    "Server",
    "Service",
    "Settings",
    "SettingsEthernet",
    "Share",
    "Shield",
    "Siren",
    "Sort",
    "Speed",
    "Stack",
    "Star",
    "Store",
    "Sun",
    "Supervisor",
    "Support",
    "Sync",
    "Table",
    "Team",
    "Template",
    "Travel",
    "Tribe",
    "Unavailable",
    "Unlock",
    "UpArrow",
    "Updates",
    "Url",
    "User",
    "Users",
    "Version",
    "Vulnerability",
    "Widget",
]
